==> haskell-random-shuffle-0.0.4-246-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-shuffle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-shuffle
version:              0.0.4
visibility:           public
id:                   random-shuffle-0.0.4-3FgPUc60nhV2vVplfBIOu
key:                  random-shuffle-0.0.4-3FgPUc60nhV2vVplfBIOu
license:              BSD-3-Clause
copyright:
    Oleg Kiselyov 2001
    Manlio Perillo 2009

maintainer:           Manlio Perillo <manlio.perillo@gmail.com>
author:               Oleg Kiselyov, Manlio Perillo, Andras Slemmer
stability:            Beta
synopsis:             Random shuffle implementation.
description:
    Random shuffle implementation, on immutable lists.
    Based on `perfect shuffle'\'' implementation by Oleg Kiselyov,
    available on http://okmij.org/ftp/Haskell/perfect-shuffle.txt

category:             System
abi:                  aa0d1c3da21947fe1c7f8acc2ec325e7
exposed:              True
exposed-modules:      System.Random.Shuffle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-shuffle
hs-libraries:         HSrandom-shuffle-0.0.4-3FgPUc60nhV2vVplfBIOu
depends:
    MonadRandom-0.6.2-1mANuf4tMpl4BsIg613rAx base-4.17.2.1
    random-1.2.1.3-AojK1F3ExhxDorHTlNe3sA

haddock-interfaces:
    /usr/share/doc/haskell-random-shuffle/html/random-shuffle.haddock

haddock-html:         /usr/share/doc/haskell-random-shuffle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-random-shuffle-0.0.4-247-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-shuffle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-shuffle
version:              0.0.4
visibility:           public
id:                   random-shuffle-0.0.4-ERUrc6t5l6w2hrezgDEIzy
key:                  random-shuffle-0.0.4-ERUrc6t5l6w2hrezgDEIzy
license:              BSD-3-Clause
copyright:
    Oleg Kiselyov 2001
    Manlio Perillo 2009

maintainer:           Manlio Perillo <manlio.perillo@gmail.com>
author:               Oleg Kiselyov, Manlio Perillo, Andras Slemmer
stability:            Beta
synopsis:             Random shuffle implementation.
description:
    Random shuffle implementation, on immutable lists.
    Based on `perfect shuffle'\'' implementation by Oleg Kiselyov,
    available on http://okmij.org/ftp/Haskell/perfect-shuffle.txt

category:             System
abi:                  7fe9dfab200596b848eff88f3a825879
exposed:              True
exposed-modules:      System.Random.Shuffle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-shuffle
hs-libraries:         HSrandom-shuffle-0.0.4-ERUrc6t5l6w2hrezgDEIzy
depends:
    MonadRandom-0.6.2-8U6Ey6iKzHu43oerNkO86R base-4.17.2.1
    random-1.2.1.3-8yAn85BRVsALc4v1F70S7L

haddock-interfaces:
    /usr/share/doc/haskell-random-shuffle/html/random-shuffle.haddock

haddock-html:         /usr/share/doc/haskell-random-shuffle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
